@@ -1,4 +1,4 @@
-#!../../src/seed
+#!/usr/bin/env seed
 
 Seed.quit(0)
 imports.testsuite.unreachable()
